import pytest
from src.validators.validator import ValidatorInterface
from src.validators.eth.validator import EthValidator


@pytest.fixture
def validator() -> ValidatorInterface:
    """Setup a validator instance for Ethereum resources"""
    return EthValidator()


@pytest.mark.parametrize("address, expected_result", [
    ("0x56Eddb7aa87536c09CCc2793473599fD21A8b17F", True),
    ("0xEF43aA45d20752aCf6D65d0AA2642D303ECf2538", True),
    ("123", False),
    ("0xEF43-A45d2_752aCf6D!5d0AA2_42D303ECf2538", False)
])
def test_is_valid_address(validator: ValidatorInterface, address: str, expected_result: bool):
    """Test whether the validator correctly identifies valid Ethereum addresses"""
    assert validator.is_address(address) == expected_result


@pytest.mark.parametrize("block_number, expected_result", [
    ("1", True),
    ("14534022", True),
    ("abc", False),
    ("123ae45", False)
])
def test_is_valid_block_number(validator: ValidatorInterface, block_number: str, expected_result: bool):
    """Tests whether the validator correctly identifies valid Ethereum block numbers"""
    assert validator.is_block(block_number) == expected_result


@pytest.mark.parametrize("tx_id, expected_result", [
    ("0x1c97dc954f0825ae93a92e0b4808b7304e1fd4d12f712e80fe247566e269e90a", True),
    ("0x0401576f273e58ac2f299c14df7f9f1955640fa439b563c283946a0593cdb993", True),
    ("123", False),
    ("0x1c97dc954f0825ae93a92e-#$_-&,:-a304e1fd4d12f712e80fe247566e269e9", False)
])
def test_is_valid_transaction_id(validator: ValidatorInterface, tx_id: str, expected_result: bool):
    """Tests whether the validator correctly identifies valid Ethereum transaction IDs"""
    assert validator.is_transaction(tx_id) == expected_result


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['multichain_explorer',
 'multichain_explorer.src',
 'multichain_explorer.src.models',
 'multichain_explorer.src.models.provider',
 'multichain_explorer.src.providers',
 'multichain_explorer.src.providers.eth',
 'multichain_explorer.src.services',
 'multichain_explorer.src.validators',
 'multichain_explorer.src.validators.eth',
 'multichain_explorer.tests.providers.eth']

package_data = \
{'': ['*'],
 'multichain_explorer': ['.git/*',
                         '.git/hooks/*',
                         '.git/info/*',
                         '.git/logs/*',
                         '.git/logs/refs/heads/*',
                         '.git/logs/refs/remotes/multichain-explorer/*',
                         '.git/objects/13/*',
                         '.git/objects/14/*',
                         '.git/objects/15/*',
                         '.git/objects/18/*',
                         '.git/objects/22/*',
                         '.git/objects/23/*',
                         '.git/objects/27/*',
                         '.git/objects/2c/*',
                         '.git/objects/2f/*',
                         '.git/objects/30/*',
                         '.git/objects/31/*',
                         '.git/objects/60/*',
                         '.git/objects/6d/*',
                         '.git/objects/6f/*',
                         '.git/objects/8a/*',
                         '.git/objects/8f/*',
                         '.git/objects/97/*',
                         '.git/objects/9a/*',
                         '.git/objects/9d/*',
                         '.git/objects/9f/*',
                         '.git/objects/a3/*',
                         '.git/objects/ae/*',
                         '.git/objects/b1/*',
                         '.git/objects/c9/*',
                         '.git/objects/cb/*',
                         '.git/objects/d5/*',
                         '.git/objects/d8/*',
                         '.git/objects/e6/*',
                         '.git/objects/ed/*',
                         '.git/objects/f0/*',
                         '.git/objects/f2/*',
                         '.git/objects/f5/*',
                         '.git/objects/f7/*',
                         '.git/refs/heads/*',
                         '.git/refs/remotes/multichain-explorer/*',
                         '.pytest_cache/*',
                         '.pytest_cache/v/cache/*']}

install_requires = \
['web3>=5.28,<6.0']

setup_kwargs = {
    'name': 'multichain-explorer',
    'version': '0.1.0',
    'description': 'A simple package to explore multiple blockchains in an homogeneous way',
    'long_description': None,
    'author': 'sdominguez894',
    'author_email': 'sdominguez894@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)



import pytest
from src.providers.provider import ProviderInterface
from src.providers.eth.provider import EthProvider


@pytest.fixture
def provider() -> ProviderInterface:
    """Setup a provider instance to enable the retrieval of Ethereum data"""
    return EthProvider()


@pytest.fixture
def address() -> str:
    """Return an address used to test the provider"""
    return "0x56Eddb7aa87536c09CCc2793473599fD21A8b17F"

def test_get_address(provider: ProviderInterface, address: str):
    """Test whether the provider returns the correct address data"""
    assert provider.get_address(address)["address"] == "0x56Eddb7aa87536c09CCc2793473599fD21A8b17F"


@pytest.fixture
def block_number() -> str:
    """Return a block number used to test the provider"""
    return "1"

def test_get_block_by_id(provider: ProviderInterface, block_number: str):
    """Test whether the provider returns the correct block data"""
    assert provider.get_block_by_id(block_number) == {
        "id": 1,
        "miner": "0x05a56E2D52c817161883f50c441c3228CFe54d9f",
        "difficulty": 17171480576,
        "timestamp": 1438269988
    }


@pytest.fixture
def tx_id() -> str:
    """Return a transaction id used to test the provider"""
    return "0x9a72dba1ff86ab68eb9e5074134b993d0eda143be6420bc73aab5c1f99b66c92"

def test_get_transaction_by_id(provider: ProviderInterface, tx_id: str):
    """Test whether the provider returns the correct transaction data"""
    assert provider.get_transaction_by_id(tx_id) == {
        "id": "0x9a72dba1ff86ab68eb9e5074134b993d0eda143be6420bc73aab5c1f99b66c92",
        "from": "0xDFd5293D8e347dFe59E90eFd55b2956a1343963d",
        "to": "0xEC471BE76460b252a9Aec4e9CE3A94933DA79616",
        "value": 67131140000000000,
        "block": 14528351
    }